using System;
using System.Windows.Forms;
using System.Drawing;

namespace ReflectionIT.SpitterDemo.Windows.Forms
{
	/// <summary>
	/// Utility class for Windows.Forms Controls.
	/// 
	/// Created by: Fons Sonnemans, Reflection IT
	/// 
	/// For questions and comments: Fons.Sonnemans@reflectionit.nl
	/// </summary>
	public class ControlUtil
	{

		/// <summary>
		/// Add a splitter between the two given controls
		/// </summary>
		/// <param name="control1">Control 1</param>
		/// <param name="control2">Control 2</param>
		/// <param name="vertical">Vertical orientation</param>
		/// <returns>The created Splitter</returns>
		public static Splitter AddSplitter(Control control1, Control control2, bool vertical)
		{
			Control parent = control1.Parent;

			// Validate
			if (parent != control2.Parent)
				throw new ArgumentException(
						"Both controls must be placed on the same Containter");

			if (parent.Controls.Count > 2)
				throw new ArgumentException(
						"There may only be 2 controls on the Container");

   			parent.SuspendLayout();

			// Move control2 before control1
			if (parent.Controls.IndexOf(control2) > parent.Controls.IndexOf(control1))
				parent.Controls.SetChildIndex(control2, 0);

			// Create splitter
			Splitter splitter = new Splitter();
			splitter.Dock = System.Windows.Forms.DockStyle.Left;

			// Set controls properties
			control2.Dock = DockStyle.Fill;
			if (vertical)
			{
				control1.Dock = DockStyle.Left;
				splitter.Dock = DockStyle.Left;
				splitter.Width = 6;
			} 
			else 
			{
				control1.Dock = DockStyle.Top;
				splitter.Dock = DockStyle.Top;
				splitter.Height = 6;
				splitter.Cursor = Cursors.HSplit;
			}

			// Add splitter to the parent in the middle
			parent.Controls.Add(splitter);
			parent.Controls.SetChildIndex(splitter,1);
			parent.ResumeLayout();

			return splitter;
		}
	}
}
